@@ -1,12 +1,12 @@
 use std::path::PathBuf;
 
 const LSU_PROXIE: &str = "http://libezp.lib.lsu.edu/login?url=";
-const COSTUM_PROXY_PATH: &str = "ezproxy.txt";
+const CUSTOM_PROXY_PATH: &str = "ezproxy.txt";
 
 pub fn generate_proxy_link(url: &str) -> String {
-    let costume_path = get_costum_proxy_path();
-    if costume_path.is_file() {
-        let proxy_url = std::fs::read_to_string(costume_path)
+    let custom_path = get_custom_proxy_path();
+    if custom_path.is_file() {
+        let proxy_url = std::fs::read_to_string(custom_path)
             .expect("Failed to read proxy.txt")
             .trim()
             .to_string();
@@ -19,16 +19,21 @@ pub fn generate_proxy_link(url: &str) -> String {
 }
 
 pub fn set_proxy(url: &str) {
-    let proxy_path = get_costum_proxy_path();
+    let proxy_path = get_custom_proxy_path();
     std::fs::write(proxy_path, url).expect("Failed to write ezproxy.txt");
 }
 
-fn get_costum_proxy_path() -> PathBuf {
+pub fn reset_proxy() {
+    let proxy_path = get_custom_proxy_path();
+    std::fs::remove_file(proxy_path).expect("Failed to remove ezproxy.txt");
+}
+
+fn get_custom_proxy_path() -> PathBuf {
     std::env::current_exe()
         .expect("Failed to get current exe")
         .parent()
         .expect("Failed to get parent directory")
-        .join(COSTUM_PROXY_PATH)
+        .join(CUSTOM_PROXY_PATH)
 }
 
 #[cfg(test)]
